@@ -526,32 +526,32 @@ def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken
 			max_id=""
 			intentos = 0
 			while itera != iter_tw:
-			try:
-				if pri ==0:
-					user=api.user_timeline(node_list1[i], count=200,tweet_mode="extended")      
-					tweets_user.append(user)
-					max_id = str(tweets_user[len(tweets_user)-1][len(tweets_user[len(tweets_user)-1])-1]._json["id_str"])
-					pri=1
-					itera = itera+1
-				else:
-					user=api.user_timeline(node_list1[i], count=200,tweet_mode="extended", max_id=max_id)
-					tweets_user.append(user)
-					max_id = str(tweets_user[len(tweets_user)-1][len(tweets_user[len(tweets_user)-1])-1]._json["id_str"])
-					itera = itera+1
-					intentos=0 # Para si justo es el primero el que no se puede extraer y no es problema de agotar claves
-			except:
-				nc = nc+1
-				n_clave = len(consumerKey)
-				if(nc == n_clave):
-					nc= 0
-				auth = tweepy.OAuthHandler(consumerKey[nc], consumerSecret[nc])
-				auth.set_access_token(accessToken[nc], accessTokenSecret[nc])
-				api = tweepy.API(auth)
-				intentos = intentos + 1
-			if(intentos == 2):         
-				list_users_noInfo.append(node_list1[i])
-				intentos = 0
-				itera=iter_tw
+				try:
+					if pri ==0:
+						user=api.user_timeline(node_list1[i], count=200,tweet_mode="extended")      
+						tweets_user.append(user)
+						max_id = str(tweets_user[len(tweets_user)-1][len(tweets_user[len(tweets_user)-1])-1]._json["id_str"])
+						pri=1
+						itera = itera+1
+					else:
+						user=api.user_timeline(node_list1[i], count=200,tweet_mode="extended", max_id=max_id)
+						tweets_user.append(user)
+						max_id = str(tweets_user[len(tweets_user)-1][len(tweets_user[len(tweets_user)-1])-1]._json["id_str"])
+						itera = itera+1
+						intentos=0 # Para si justo es el primero el que no se puede extraer y no es problema de agotar claves
+				except:
+					nc = nc+1
+					n_clave = len(consumerKey)
+					if(nc == n_clave):
+						nc= 0
+					auth = tweepy.OAuthHandler(consumerKey[nc], consumerSecret[nc])
+					auth.set_access_token(accessToken[nc], accessTokenSecret[nc])
+					api = tweepy.API(auth)
+					intentos = intentos + 1
+					if(intentos == 2):         
+						list_users_noInfo.append(node_list1[i])
+						intentos = 0
+						itera=iter_tw
 			i = i+1       
 		destino2 = time.time()
 		aux=[]
@@ -577,10 +577,10 @@ def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken
 			if len(list_users_noInfo) !=0:
 				nodes = pd.DataFrame()
 				nodes["nodos"] = list_users_noInfo
-			if path.exists("/content/node_without_"+fichero):
-				nodes.to_csv("node_without_"+ fichero, mode ="a",index=False, header=False)          
-			else:
-				nodes.to_csv("node_without_"+ fichero, index=False)
+				if path.exists("/content/node_without_"+fichero):
+					nodes.to_csv("node_without_"+ fichero, mode ="a",index=False, header=False)          
+				else:
+					nodes.to_csv("node_without_"+ fichero, index=False)
 			k = k+profile_iter        
 			if ultima ==1:          
 				ultima =2
@@ -1085,7 +1085,7 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
       
     return data,tweets_df
 	
-def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups):
+def more_tweets_required(df,df_graph_features,consumerKey,consumerSecret,accessToken,accessTokenSecret,n_groups,save_by):
 	df_evaluate = df[(df["evaluate_NLP"] !="No") & (df["evaluate_NLP"] !="More Data")]
 	node_list_moreData = list(df[df["evaluate_NLP"]=="More Data"]["screen_name"])
 	if len(node_list_moreData) >0:
